==> kubernetes-model-core-6.7.2-sources.jar: io/fabric8/kubernetes/api/model/version/InfoBuilder.java <==
package io.fabric8.kubernetes.api.model.version;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class InfoBuilder extends InfoFluentImpl<InfoBuilder> implements VisitableBuilder<Info,InfoBuilder>{
  public InfoBuilder() {
    this(false);
  }
  public InfoBuilder(Boolean validationEnabled) {
    this(new Info(), validationEnabled);
  }
  public InfoBuilder(InfoFluent<?> fluent) {
    this(fluent, false);
  }
  public InfoBuilder(InfoFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new Info(), validationEnabled);
  }
  public InfoBuilder(InfoFluent<?> fluent,Info instance) {
    this(fluent, instance, false);
  }
  public InfoBuilder(InfoFluent<?> fluent,Info instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    if (instance != null) {
      fluent.withBuildDate(instance.getBuildDate());
      fluent.withCompiler(instance.getCompiler());
      fluent.withGitCommit(instance.getGitCommit());
      fluent.withGitTreeState(instance.getGitTreeState());
      fluent.withGitVersion(instance.getGitVersion());
      fluent.withGoVersion(instance.getGoVersion());
      fluent.withMajor(instance.getMajor());
      fluent.withMinor(instance.getMinor());
      fluent.withPlatform(instance.getPlatform());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public InfoBuilder(Info instance) {
    this(instance,false);
  }
  public InfoBuilder(Info instance,Boolean validationEnabled) {
    this.fluent = this; 
    if (instance != null) {
      this.withBuildDate(instance.getBuildDate());
      this.withCompiler(instance.getCompiler());
      this.withGitCommit(instance.getGitCommit());
      this.withGitTreeState(instance.getGitTreeState());
      this.withGitVersion(instance.getGitVersion());
      this.withGoVersion(instance.getGoVersion());
      this.withMajor(instance.getMajor());
      this.withMinor(instance.getMinor());
      this.withPlatform(instance.getPlatform());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  InfoFluent<?> fluent;
  Boolean validationEnabled;
  public Info build() {
    Info buildable = new Info(fluent.getBuildDate(),fluent.getCompiler(),fluent.getGitCommit(),fluent.getGitTreeState(),fluent.getGitVersion(),fluent.getGoVersion(),fluent.getMajor(),fluent.getMinor(),fluent.getPlatform());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}

==> kubernetes-model-core-6.8.0-sources.jar: io/fabric8/kubernetes/api/model/version/InfoBuilder.java <==
package io.fabric8.kubernetes.api.model.version;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class InfoBuilder extends InfoFluent<InfoBuilder> implements VisitableBuilder<Info,InfoBuilder>{
  public InfoBuilder() {
    this(false);
  }
  public InfoBuilder(Boolean validationEnabled) {
    this(new Info(), validationEnabled);
  }
  public InfoBuilder(InfoFluent<?> fluent) {
    this(fluent, false);
  }
  public InfoBuilder(InfoFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new Info(), validationEnabled);
  }
  public InfoBuilder(InfoFluent<?> fluent,Info instance) {
    this(fluent, instance, false);
  }
  public InfoBuilder(InfoFluent<?> fluent,Info instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new Info());

    if (instance != null) {
      fluent.withBuildDate(instance.getBuildDate());
      fluent.withCompiler(instance.getCompiler());
      fluent.withGitCommit(instance.getGitCommit());
      fluent.withGitTreeState(instance.getGitTreeState());
      fluent.withGitVersion(instance.getGitVersion());
      fluent.withGoVersion(instance.getGoVersion());
      fluent.withMajor(instance.getMajor());
      fluent.withMinor(instance.getMinor());
      fluent.withPlatform(instance.getPlatform());
      fluent.withBuildDate(instance.getBuildDate());
      fluent.withCompiler(instance.getCompiler());
      fluent.withGitCommit(instance.getGitCommit());
      fluent.withGitTreeState(instance.getGitTreeState());
      fluent.withGitVersion(instance.getGitVersion());
      fluent.withGoVersion(instance.getGoVersion());
      fluent.withMajor(instance.getMajor());
      fluent.withMinor(instance.getMinor());
      fluent.withPlatform(instance.getPlatform());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public InfoBuilder(Info instance) {
    this(instance,false);
  }
  public InfoBuilder(Info instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new Info());

    if (instance != null) {
      this.withBuildDate(instance.getBuildDate());
      this.withCompiler(instance.getCompiler());
      this.withGitCommit(instance.getGitCommit());
      this.withGitTreeState(instance.getGitTreeState());
      this.withGitVersion(instance.getGitVersion());
      this.withGoVersion(instance.getGoVersion());
      this.withMajor(instance.getMajor());
      this.withMinor(instance.getMinor());
      this.withPlatform(instance.getPlatform());
      this.withBuildDate(instance.getBuildDate());
      this.withCompiler(instance.getCompiler());
      this.withGitCommit(instance.getGitCommit());
      this.withGitTreeState(instance.getGitTreeState());
      this.withGitVersion(instance.getGitVersion());
      this.withGoVersion(instance.getGoVersion());
      this.withMajor(instance.getMajor());
      this.withMinor(instance.getMinor());
      this.withPlatform(instance.getPlatform());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  InfoFluent<?> fluent;
  Boolean validationEnabled;
  public Info build() {
    Info buildable = new Info(fluent.getBuildDate(),fluent.getCompiler(),fluent.getGitCommit(),fluent.getGitTreeState(),fluent.getGitVersion(),fluent.getGoVersion(),fluent.getMajor(),fluent.getMinor(),fluent.getPlatform());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
